@@ -22,12 +22,12 @@ def _get_pep386version():
 
     sitk_major = "2"
     sitk_minor = "5"
-    sitk_patch = "2"
+    sitk_patch = "3"
     sitk_tweak = ""
     sitk_rc = ""
     sitk_post = ""
     sitk_dev = ""
-    sitk_hash = "2018b"
+    sitk_hash = "31617"
 
     version = sitk_major + "." + sitk_minor
 
